from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.indexing_task_dto import IndexingTaskDto


T = TypeVar("T", bound="CreateIndexingTaskResponse")


@_attrs_define
class CreateIndexingTaskResponse:
    """
    Attributes:
        task_rid (str | Unset):
        task (IndexingTaskDto | Unset):
        created (bool | Unset):
    """

    task_rid: str | Unset = UNSET
    task: IndexingTaskDto | Unset = UNSET
    created: bool | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        task_rid = self.task_rid

        task: dict[str, Any] | Unset = UNSET
        if not isinstance(self.task, Unset):
            task = self.task.to_dict()

        created = self.created

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if task_rid is not UNSET:
            field_dict["taskRid"] = task_rid
        if task is not UNSET:
            field_dict["task"] = task
        if created is not UNSET:
            field_dict["created"] = created

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.indexing_task_dto import IndexingTaskDto

        d = dict(src_dict)
        task_rid = d.pop("taskRid", UNSET)

        _task = d.pop("task", UNSET)
        task: IndexingTaskDto | Unset
        if isinstance(_task, Unset):
            task = UNSET
        else:
            task = IndexingTaskDto.from_dict(_task)

        created = d.pop("created", UNSET)

        create_indexing_task_response = cls(
            task_rid=task_rid,
            task=task,
            created=created,
        )

        create_indexing_task_response.additional_properties = d
        return create_indexing_task_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.run_status_dto import RunStatusDto
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.get_worker_run_response_inputs import GetWorkerRunResponseInputs


T = TypeVar("T", bound="GetWorkerRunResponse")


@_attrs_define
class GetWorkerRunResponse:
    """
    Attributes:
        run_rid (str | Unset):
        status (RunStatusDto | Unset):
        started_by_user_id (str | Unset):
        created_at (datetime.datetime | Unset):
        inputs (GetWorkerRunResponseInputs | Unset):
    """

    run_rid: str | Unset = UNSET
    status: RunStatusDto | Unset = UNSET
    started_by_user_id: str | Unset = UNSET
    created_at: datetime.datetime | Unset = UNSET
    inputs: GetWorkerRunResponseInputs | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        run_rid = self.run_rid

        status: str | Unset = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        started_by_user_id = self.started_by_user_id

        created_at: str | Unset = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        inputs: dict[str, Any] | Unset = UNSET
        if not isinstance(self.inputs, Unset):
            inputs = self.inputs.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if run_rid is not UNSET:
            field_dict["runRid"] = run_rid
        if status is not UNSET:
            field_dict["status"] = status
        if started_by_user_id is not UNSET:
            field_dict["startedByUserId"] = started_by_user_id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if inputs is not UNSET:
            field_dict["inputs"] = inputs

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_worker_run_response_inputs import GetWorkerRunResponseInputs

        d = dict(src_dict)
        run_rid = d.pop("runRid", UNSET)

        _status = d.pop("status", UNSET)
        status: RunStatusDto | Unset
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = RunStatusDto(_status)

        started_by_user_id = d.pop("startedByUserId", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: datetime.datetime | Unset
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _inputs = d.pop("inputs", UNSET)
        inputs: GetWorkerRunResponseInputs | Unset
        if isinstance(_inputs, Unset):
            inputs = UNSET
        else:
            inputs = GetWorkerRunResponseInputs.from_dict(_inputs)

        get_worker_run_response = cls(
            run_rid=run_rid,
            status=status,
            started_by_user_id=started_by_user_id,
            created_at=created_at,
            inputs=inputs,
        )

        get_worker_run_response.additional_properties = d
        return get_worker_run_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.indexing_schedule_dto import IndexingScheduleDto


T = TypeVar("T", bound="ListIndexingSchedulesResponse")


@_attrs_define
class ListIndexingSchedulesResponse:
    """
    Attributes:
        schedules (list[IndexingScheduleDto] | Unset):
        total_count (int | Unset):
        next_offset (int | None | Unset):
    """

    schedules: list[IndexingScheduleDto] | Unset = UNSET
    total_count: int | Unset = UNSET
    next_offset: int | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        schedules: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.schedules, Unset):
            schedules = []
            for schedules_item_data in self.schedules:
                schedules_item = schedules_item_data.to_dict()
                schedules.append(schedules_item)

        total_count = self.total_count

        next_offset: int | None | Unset
        if isinstance(self.next_offset, Unset):
            next_offset = UNSET
        else:
            next_offset = self.next_offset

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schedules is not UNSET:
            field_dict["schedules"] = schedules
        if total_count is not UNSET:
            field_dict["totalCount"] = total_count
        if next_offset is not UNSET:
            field_dict["nextOffset"] = next_offset

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.indexing_schedule_dto import IndexingScheduleDto

        d = dict(src_dict)
        _schedules = d.pop("schedules", UNSET)
        schedules: list[IndexingScheduleDto] | Unset = UNSET
        if _schedules is not UNSET:
            schedules = []
            for schedules_item_data in _schedules:
                schedules_item = IndexingScheduleDto.from_dict(schedules_item_data)

                schedules.append(schedules_item)

        total_count = d.pop("totalCount", UNSET)

        def _parse_next_offset(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        next_offset = _parse_next_offset(d.pop("nextOffset", UNSET))

        list_indexing_schedules_response = cls(
            schedules=schedules,
            total_count=total_count,
            next_offset=next_offset,
        )

        list_indexing_schedules_response.additional_properties = d
        return list_indexing_schedules_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserInfoResponse")


@_attrs_define
class UserInfoResponse:
    """User information response

    Attributes:
        user_id (str): User ID/subject from JWT
        username (None | str | Unset): Username
        email (None | str | Unset): Email address
        first_name (None | str | Unset): First name
        last_name (None | str | Unset): Last name
    """

    user_id: str
    username: None | str | Unset = UNSET
    email: None | str | Unset = UNSET
    first_name: None | str | Unset = UNSET
    last_name: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        username: None | str | Unset
        if isinstance(self.username, Unset):
            username = UNSET
        else:
            username = self.username

        email: None | str | Unset
        if isinstance(self.email, Unset):
            email = UNSET
        else:
            email = self.email

        first_name: None | str | Unset
        if isinstance(self.first_name, Unset):
            first_name = UNSET
        else:
            first_name = self.first_name

        last_name: None | str | Unset
        if isinstance(self.last_name, Unset):
            last_name = UNSET
        else:
            last_name = self.last_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "userId": user_id,
            }
        )
        if username is not UNSET:
            field_dict["username"] = username
        if email is not UNSET:
            field_dict["email"] = email
        if first_name is not UNSET:
            field_dict["firstName"] = first_name
        if last_name is not UNSET:
            field_dict["lastName"] = last_name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId")

        def _parse_username(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        username = _parse_username(d.pop("username", UNSET))

        def _parse_email(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        email = _parse_email(d.pop("email", UNSET))

        def _parse_first_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        first_name = _parse_first_name(d.pop("firstName", UNSET))

        def _parse_last_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        last_name = _parse_last_name(d.pop("lastName", UNSET))

        user_info_response = cls(
            user_id=user_id,
            username=username,
            email=email,
            first_name=first_name,
            last_name=last_name,
        )

        user_info_response.additional_properties = d
        return user_info_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkerV2NextPageToken")


@_attrs_define
class WorkerV2NextPageToken:
    """
    Attributes:
        offset_for_worker_run_events (int | Unset):
        offset_for_input_request_events (int | Unset):
    """

    offset_for_worker_run_events: int | Unset = UNSET
    offset_for_input_request_events: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        offset_for_worker_run_events = self.offset_for_worker_run_events

        offset_for_input_request_events = self.offset_for_input_request_events

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if offset_for_worker_run_events is not UNSET:
            field_dict["offsetForWorkerRunEvents"] = offset_for_worker_run_events
        if offset_for_input_request_events is not UNSET:
            field_dict["offsetForInputRequestEvents"] = offset_for_input_request_events

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        offset_for_worker_run_events = d.pop("offsetForWorkerRunEvents", UNSET)

        offset_for_input_request_events = d.pop("offsetForInputRequestEvents", UNSET)

        worker_v2_next_page_token = cls(
            offset_for_worker_run_events=offset_for_worker_run_events,
            offset_for_input_request_events=offset_for_input_request_events,
        )

        worker_v2_next_page_token.additional_properties = d
        return worker_v2_next_page_token

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from io import BytesIO
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from .. import types
from ..types import UNSET, File, Unset

T = TypeVar("T", bound="PostManagedFileSystemUploadRequest")


@_attrs_define
class PostManagedFileSystemUploadRequest:
    """
    Attributes:
        file (File):
        filename (str):
        parent (None | str | Unset):
    """

    file: File
    filename: str
    parent: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        file = self.file.to_tuple()

        filename = self.filename

        parent: None | str | Unset
        if isinstance(self.parent, Unset):
            parent = UNSET
        else:
            parent = self.parent

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "file": file,
                "filename": filename,
            }
        )
        if parent is not UNSET:
            field_dict["parent"] = parent

        return field_dict

    def to_multipart(self) -> types.RequestFiles:
        files: types.RequestFiles = []

        files.append(("file", self.file.to_tuple()))

        files.append(("filename", (None, str(self.filename).encode(), "text/plain")))

        if not isinstance(self.parent, Unset):
            if isinstance(self.parent, str):
                files.append(("parent", (None, str(self.parent).encode(), "text/plain")))
            else:
                files.append(("parent", (None, str(self.parent).encode(), "text/plain")))

        for prop_name, prop in self.additional_properties.items():
            files.append((prop_name, (None, str(prop).encode(), "text/plain")))

        return files

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        file = File(payload=BytesIO(d.pop("file")))

        filename = d.pop("filename")

        def _parse_parent(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        parent = _parse_parent(d.pop("parent", UNSET))

        post_managed_file_system_upload_request = cls(
            file=file,
            filename=filename,
            parent=parent,
        )

        post_managed_file_system_upload_request.additional_properties = d
        return post_managed_file_system_upload_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UploadResourceResponseV2")


@_attrs_define
class UploadResourceResponseV2:
    """
    Attributes:
        resource_id (str | Unset):
        uri (str | Unset):
        size_in_bytes (int | Unset):
    """

    resource_id: str | Unset = UNSET
    uri: str | Unset = UNSET
    size_in_bytes: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        resource_id = self.resource_id

        uri = self.uri

        size_in_bytes = self.size_in_bytes

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if resource_id is not UNSET:
            field_dict["resourceId"] = resource_id
        if uri is not UNSET:
            field_dict["uri"] = uri
        if size_in_bytes is not UNSET:
            field_dict["sizeInBytes"] = size_in_bytes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        resource_id = d.pop("resourceId", UNSET)

        uri = d.pop("uri", UNSET)

        size_in_bytes = d.pop("sizeInBytes", UNSET)

        upload_resource_response_v2 = cls(
            resource_id=resource_id,
            uri=uri,
            size_in_bytes=size_in_bytes,
        )

        upload_resource_response_v2.additional_properties = d
        return upload_resource_response_v2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RunStatusDto(str, Enum):
    COMPLETED = "COMPLETED"
    ERROR_CLIENT = "ERROR_CLIENT"
    ERROR_REJECTED = "ERROR_REJECTED"
    ERROR_RETRY_LIMIT_EXCEEDED = "ERROR_RETRY_LIMIT_EXCEEDED"
    ERROR_SERVER = "ERROR_SERVER"
    ERROR_TIMEOUT = "ERROR_TIMEOUT"
    PAUSED_FOR_INPUT = "PAUSED_FOR_INPUT"
    QUEUED = "QUEUED"
    QUEUED_FOR_RESUME = "QUEUED_FOR_RESUME"
    RUNNING = "RUNNING"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="IndexerDto")


@_attrs_define
class IndexerDto:
    """Indexer service details, including supported index version range and capabilities.

    Attributes:
        indexer_rid (str | Unset):
        target_index_version (int | Unset):
        minimum_supported_index_version (int | Unset):
    """

    indexer_rid: str | Unset = UNSET
    target_index_version: int | Unset = UNSET
    minimum_supported_index_version: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        indexer_rid = self.indexer_rid

        target_index_version = self.target_index_version

        minimum_supported_index_version = self.minimum_supported_index_version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if indexer_rid is not UNSET:
            field_dict["indexerRid"] = indexer_rid
        if target_index_version is not UNSET:
            field_dict["targetIndexVersion"] = target_index_version
        if minimum_supported_index_version is not UNSET:
            field_dict["minimumSupportedIndexVersion"] = minimum_supported_index_version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        indexer_rid = d.pop("indexerRid", UNSET)

        target_index_version = d.pop("targetIndexVersion", UNSET)

        minimum_supported_index_version = d.pop("minimumSupportedIndexVersion", UNSET)

        indexer_dto = cls(
            indexer_rid=indexer_rid,
            target_index_version=target_index_version,
            minimum_supported_index_version=minimum_supported_index_version,
        )

        indexer_dto.additional_properties = d
        return indexer_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .action_type import ActionType
from .add_tag_to_file_request import AddTagToFileRequest
from .azure_blob_connection_settings_api_dto import AzureBlobConnectionSettingsApiDto
from .azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto
from .biotech_analysis_api_dto import BiotechAnalysisApiDto
from .biotech_analysis_image_annotated_citation_api_dto import BiotechAnalysisImageAnnotatedCitationApiDto
from .bulk_get_citations_request import BulkGetCitationsRequest
from .bulk_get_citations_response import BulkGetCitationsResponse
from .citation_api_dto import CitationApiDto
from .connection_api_dto import ConnectionApiDto
from .create_connection_request import CreateConnectionRequest
from .create_connection_response import CreateConnectionResponse
from .create_file_system_response import CreateFileSystemResponse
from .create_folder_request import CreateFolderRequest
from .create_folder_response import CreateFolderResponse
from .create_folder_response_v2 import CreateFolderResponseV2
from .create_indexing_schedule_request import CreateIndexingScheduleRequest
from .create_indexing_schedule_request_indexing_settings import CreateIndexingScheduleRequestIndexingSettings
from .create_indexing_schedule_response import CreateIndexingScheduleResponse
from .create_indexing_task_request import CreateIndexingTaskRequest
from .create_indexing_task_request_settings import CreateIndexingTaskRequestSettings
from .create_indexing_task_response import CreateIndexingTaskResponse
from .create_managed_file_system_request import CreateManagedFileSystemRequest
from .create_remote_file_system_request import CreateRemoteFileSystemRequest
from .create_tag_request import CreateTagRequest
from .create_tag_response import CreateTagResponse
from .cron_trigger import CronTrigger
from .execution_trigger_reason import ExecutionTriggerReason
from .get_citation_output_uri_response import GetCitationOutputUriResponse
from .get_connection_response import GetConnectionResponse
from .get_indexer_response import GetIndexerResponse
from .get_indexing_schedule_response import GetIndexingScheduleResponse
from .get_indexing_task_response import GetIndexingTaskResponse
from .get_metadata_response import GetMetadataResponse
from .get_parent_response import GetParentResponse
from .get_parent_uri_response import GetParentUriResponse
from .get_run_event_rating_response import GetRunEventRatingResponse
from .get_signed_url_response import GetSignedUrlResponse
from .get_worker_events_response import GetWorkerEventsResponse
from .get_worker_events_v2_response import GetWorkerEventsV2Response
from .get_worker_metadata_response import GetWorkerMetadataResponse
from .get_worker_run_response import GetWorkerRunResponse
from .get_worker_run_response_inputs import GetWorkerRunResponseInputs
from .get_worker_status_response import GetWorkerStatusResponse
from .get_workers_response import GetWorkersResponse
from .get_workers_response_worker_identifiers import GetWorkersResponseWorkerIdentifiers
from .get_workflow_events_response import GetWorkflowEventsResponse
from .highlighted_text_citation_metadata_api_dto import HighlightedTextCitationMetadataApiDto
from .image_detection_box_api_dto import ImageDetectionBoxApiDto
from .indexer_dto import IndexerDto
from .indexing_action_dto import IndexingActionDto
from .indexing_action_status import IndexingActionStatus
from .indexing_schedule_dto import IndexingScheduleDto
from .indexing_schedule_dto_indexing_settings import IndexingScheduleDtoIndexingSettings
from .indexing_task_dto import IndexingTaskDto
from .indexing_task_dto_settings import IndexingTaskDtoSettings
from .indexing_task_status import IndexingTaskStatus
from .info_event import InfoEvent
from .info_event_1 import InfoEvent1
from .interrupt_workflow_run_request import InterruptWorkflowRunRequest
from .interval_trigger import IntervalTrigger
from .invoke_workflow_update_request import InvokeWorkflowUpdateRequest
from .invoke_workflow_update_request_inputs import InvokeWorkflowUpdateRequestInputs
from .invoke_workflow_update_response import InvokeWorkflowUpdateResponse
from .invoke_workflow_update_response_result_type_0_item import InvokeWorkflowUpdateResponseResultType0Item
from .json_node import JsonNode
from .json_node_type import JsonNodeType
from .list_all_file_systems_response import ListAllFileSystemsResponse
from .list_all_file_systems_response_file_systems import ListAllFileSystemsResponseFileSystems
from .list_file_system_response import ListFileSystemResponse
from .list_file_system_response_resources import ListFileSystemResponseResources
from .list_indexers_response import ListIndexersResponse
from .list_indexers_response_indexers import ListIndexersResponseIndexers
from .list_indexing_actions_response import ListIndexingActionsResponse
from .list_indexing_schedules_response import ListIndexingSchedulesResponse
from .list_schedule_executions_response import ListScheduleExecutionsResponse
from .list_tags_response import ListTagsResponse
from .list_users_response import ListUsersResponse
from .managed_file_system_api_dto import ManagedFileSystemApiDto
from .me_response import MeResponse
from .on_upload_trigger import OnUploadTrigger
from .paged_list_file_system_response import PagedListFileSystemResponse
from .post_managed_file_system_upload_request import PostManagedFileSystemUploadRequest
from .post_rating_request import PostRatingRequest
from .post_run_event_rating_response import PostRunEventRatingResponse
from .post_worker_run_request import PostWorkerRunRequest
from .post_worker_run_request_inputs import PostWorkerRunRequestInputs
from .post_worker_run_response import PostWorkerRunResponse
from .post_workflow_run_request import PostWorkflowRunRequest
from .post_workflow_run_request_inputs import PostWorkflowRunRequestInputs
from .post_workflow_run_response import PostWorkflowRunResponse
from .progress_event import ProgressEvent
from .progress_event_1 import ProgressEvent1
from .progress_event_1_payload import ProgressEvent1Payload
from .progress_event_payload import ProgressEventPayload
from .query_workflow_request import QueryWorkflowRequest
from .query_workflow_request_inputs_type_0_item import QueryWorkflowRequestInputsType0Item
from .query_workflow_response import QueryWorkflowResponse
from .query_workflow_response_result_type_0_item import QueryWorkflowResponseResultType0Item
from .rating_dto_worker_run_event_rating_secondary_id import RatingDtoWorkerRunEventRatingSecondaryId
from .remote_file_system_api_dto import RemoteFileSystemApiDto
from .remove_tag_from_file_request import RemoveTagFromFileRequest
from .request_for_input_event import RequestForInputEvent
from .request_for_input_event_provided_data_type_0 import RequestForInputEventProvidedDataType0
from .request_for_input_event_requested_data import RequestForInputEventRequestedData
from .resource_entry_dto import ResourceEntryDto
from .resource_identifier import ResourceIdentifier
from .resource_metadata_dto import ResourceMetadataDto
from .resource_type_dto import ResourceTypeDto
from .resume_run_response import ResumeRunResponse
from .run_status_dto import RunStatusDto
from .s3_connection_settings_api_dto import S3ConnectionSettingsApiDto
from .s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto
from .schedule_execution_dto import ScheduleExecutionDto
from .schema import Schema
from .schema_location import SchemaLocation
from .schema_unprocessed_properties import SchemaUnprocessedProperties
from .send_workflow_signal_request import SendWorkflowSignalRequest
from .send_workflow_signal_request_inputs import SendWorkflowSignalRequestInputs
from .start_execution_response import StartExecutionResponse
from .tag_info import TagInfo
from .update_indexing_schedule_request import UpdateIndexingScheduleRequest
from .update_indexing_schedule_request_indexing_settings_type_0 import (
    UpdateIndexingScheduleRequestIndexingSettingsType0,
)
from .update_indexing_schedule_response import UpdateIndexingScheduleResponse
from .update_tag_request import UpdateTagRequest
from .update_tag_response import UpdateTagResponse
from .upload_file_overwrite import UploadFileOverwrite
from .upload_file_to_managed_file_system_response import UploadFileToManagedFileSystemResponse
from .upload_resource_response_v2 import UploadResourceResponseV2
from .uri_file_upload_request import UriFileUploadRequest
from .user_info_response import UserInfoResponse
from .user_input_event import UserInputEvent
from .user_input_event_input import UserInputEventInput
from .user_request_for_input_event import UserRequestForInputEvent
from .user_request_for_input_event_provided_data_type_0 import UserRequestForInputEventProvidedDataType0
from .user_request_for_input_event_requested_data import UserRequestForInputEventRequestedData
from .web_page_citation_metadata_api_dto import WebPageCitationMetadataApiDto
from .worker_metadata_dto import WorkerMetadataDto
from .worker_metadata_dto_input_schema import WorkerMetadataDtoInputSchema
from .worker_metadata_dto_response_schema import WorkerMetadataDtoResponseSchema
from .worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId
from .worker_v2_next_page_token import WorkerV2NextPageToken
from .workflow_event import WorkflowEvent
from .workflow_status_response import WorkflowStatusResponse

__all__ = (
    "ActionType",
    "AddTagToFileRequest",
    "AzureBlobConnectionSettingsApiDto",
    "AzureBlobFileSystemRootMetadataApiDto",
    "BiotechAnalysisApiDto",
    "BiotechAnalysisImageAnnotatedCitationApiDto",
    "BulkGetCitationsRequest",
    "BulkGetCitationsResponse",
    "CitationApiDto",
    "ConnectionApiDto",
    "CreateConnectionRequest",
    "CreateConnectionResponse",
    "CreateFileSystemResponse",
    "CreateFolderRequest",
    "CreateFolderResponse",
    "CreateFolderResponseV2",
    "CreateIndexingScheduleRequest",
    "CreateIndexingScheduleRequestIndexingSettings",
    "CreateIndexingScheduleResponse",
    "CreateIndexingTaskRequest",
    "CreateIndexingTaskRequestSettings",
    "CreateIndexingTaskResponse",
    "CreateManagedFileSystemRequest",
    "CreateRemoteFileSystemRequest",
    "CreateTagRequest",
    "CreateTagResponse",
    "CronTrigger",
    "ExecutionTriggerReason",
    "GetCitationOutputUriResponse",
    "GetConnectionResponse",
    "GetIndexerResponse",
    "GetIndexingScheduleResponse",
    "GetIndexingTaskResponse",
    "GetMetadataResponse",
    "GetParentResponse",
    "GetParentUriResponse",
    "GetRunEventRatingResponse",
    "GetSignedUrlResponse",
    "GetWorkerEventsResponse",
    "GetWorkerEventsV2Response",
    "GetWorkerMetadataResponse",
    "GetWorkerRunResponse",
    "GetWorkerRunResponseInputs",
    "GetWorkersResponse",
    "GetWorkersResponseWorkerIdentifiers",
    "GetWorkerStatusResponse",
    "GetWorkflowEventsResponse",
    "HighlightedTextCitationMetadataApiDto",
    "ImageDetectionBoxApiDto",
    "IndexerDto",
    "IndexingActionDto",
    "IndexingActionStatus",
    "IndexingScheduleDto",
    "IndexingScheduleDtoIndexingSettings",
    "IndexingTaskDto",
    "IndexingTaskDtoSettings",
    "IndexingTaskStatus",
    "InfoEvent",
    "InfoEvent1",
    "InterruptWorkflowRunRequest",
    "IntervalTrigger",
    "InvokeWorkflowUpdateRequest",
    "InvokeWorkflowUpdateRequestInputs",
    "InvokeWorkflowUpdateResponse",
    "InvokeWorkflowUpdateResponseResultType0Item",
    "JsonNode",
    "JsonNodeType",
    "ListAllFileSystemsResponse",
    "ListAllFileSystemsResponseFileSystems",
    "ListFileSystemResponse",
    "ListFileSystemResponseResources",
    "ListIndexersResponse",
    "ListIndexersResponseIndexers",
    "ListIndexingActionsResponse",
    "ListIndexingSchedulesResponse",
    "ListScheduleExecutionsResponse",
    "ListTagsResponse",
    "ListUsersResponse",
    "ManagedFileSystemApiDto",
    "MeResponse",
    "OnUploadTrigger",
    "PagedListFileSystemResponse",
    "PostManagedFileSystemUploadRequest",
    "PostRatingRequest",
    "PostRunEventRatingResponse",
    "PostWorkerRunRequest",
    "PostWorkerRunRequestInputs",
    "PostWorkerRunResponse",
    "PostWorkflowRunRequest",
    "PostWorkflowRunRequestInputs",
    "PostWorkflowRunResponse",
    "ProgressEvent",
    "ProgressEvent1",
    "ProgressEvent1Payload",
    "ProgressEventPayload",
    "QueryWorkflowRequest",
    "QueryWorkflowRequestInputsType0Item",
    "QueryWorkflowResponse",
    "QueryWorkflowResponseResultType0Item",
    "RatingDtoWorkerRunEventRatingSecondaryId",
    "RemoteFileSystemApiDto",
    "RemoveTagFromFileRequest",
    "RequestForInputEvent",
    "RequestForInputEventProvidedDataType0",
    "RequestForInputEventRequestedData",
    "ResourceEntryDto",
    "ResourceIdentifier",
    "ResourceMetadataDto",
    "ResourceTypeDto",
    "ResumeRunResponse",
    "RunStatusDto",
    "S3ConnectionSettingsApiDto",
    "S3FileSystemRootMetadataApiDto",
    "ScheduleExecutionDto",
    "Schema",
    "SchemaLocation",
    "SchemaUnprocessedProperties",
    "SendWorkflowSignalRequest",
    "SendWorkflowSignalRequestInputs",
    "StartExecutionResponse",
    "TagInfo",
    "UpdateIndexingScheduleRequest",
    "UpdateIndexingScheduleRequestIndexingSettingsType0",
    "UpdateIndexingScheduleResponse",
    "UpdateTagRequest",
    "UpdateTagResponse",
    "UploadFileOverwrite",
    "UploadFileToManagedFileSystemResponse",
    "UploadResourceResponseV2",
    "UriFileUploadRequest",
    "UserInfoResponse",
    "UserInputEvent",
    "UserInputEventInput",
    "UserRequestForInputEvent",
    "UserRequestForInputEventProvidedDataType0",
    "UserRequestForInputEventRequestedData",
    "WebPageCitationMetadataApiDto",
    "WorkerMetadataDto",
    "WorkerMetadataDtoInputSchema",
    "WorkerMetadataDtoResponseSchema",
    "WorkerRunEventRatingSecondaryId",
    "WorkerV2NextPageToken",
    "WorkflowEvent",
    "WorkflowStatusResponse",
)



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.worker_metadata_dto import WorkerMetadataDto


T = TypeVar("T", bound="GetWorkerMetadataResponse")


@_attrs_define
class GetWorkerMetadataResponse:
    """
    Attributes:
        worker_metadata (WorkerMetadataDto | Unset):
    """

    worker_metadata: WorkerMetadataDto | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        worker_metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.worker_metadata, Unset):
            worker_metadata = self.worker_metadata.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if worker_metadata is not UNSET:
            field_dict["workerMetadata"] = worker_metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.worker_metadata_dto import WorkerMetadataDto

        d = dict(src_dict)
        _worker_metadata = d.pop("workerMetadata", UNSET)
        worker_metadata: WorkerMetadataDto | Unset
        if isinstance(_worker_metadata, Unset):
            worker_metadata = UNSET
        else:
            worker_metadata = WorkerMetadataDto.from_dict(_worker_metadata)

        get_worker_metadata_response = cls(
            worker_metadata=worker_metadata,
        )

        get_worker_metadata_response.additional_properties = d
        return get_worker_metadata_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ResourceIdentifier")


@_attrs_define
class ResourceIdentifier:
    """
    Attributes:
        resource_identifier (str | Unset):
        service_index (int | Unset):
        instance_index (int | Unset):
        type_index (int | Unset):
        service (str | Unset):
        instance (str | Unset):
        type_ (str | Unset):
        locator (str | Unset):
    """

    resource_identifier: str | Unset = UNSET
    service_index: int | Unset = UNSET
    instance_index: int | Unset = UNSET
    type_index: int | Unset = UNSET
    service: str | Unset = UNSET
    instance: str | Unset = UNSET
    type_: str | Unset = UNSET
    locator: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        resource_identifier = self.resource_identifier

        service_index = self.service_index

        instance_index = self.instance_index

        type_index = self.type_index

        service = self.service

        instance = self.instance

        type_ = self.type_

        locator = self.locator

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if resource_identifier is not UNSET:
            field_dict["resourceIdentifier"] = resource_identifier
        if service_index is not UNSET:
            field_dict["serviceIndex"] = service_index
        if instance_index is not UNSET:
            field_dict["instanceIndex"] = instance_index
        if type_index is not UNSET:
            field_dict["typeIndex"] = type_index
        if service is not UNSET:
            field_dict["service"] = service
        if instance is not UNSET:
            field_dict["instance"] = instance
        if type_ is not UNSET:
            field_dict["type"] = type_
        if locator is not UNSET:
            field_dict["locator"] = locator

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        resource_identifier = d.pop("resourceIdentifier", UNSET)

        service_index = d.pop("serviceIndex", UNSET)

        instance_index = d.pop("instanceIndex", UNSET)

        type_index = d.pop("typeIndex", UNSET)

        service = d.pop("service", UNSET)

        instance = d.pop("instance", UNSET)

        type_ = d.pop("type", UNSET)

        locator = d.pop("locator", UNSET)

        resource_identifier = cls(
            resource_identifier=resource_identifier,
            service_index=service_index,
            instance_index=instance_index,
            type_index=type_index,
            service=service,
            instance=instance,
            type_=type_,
            locator=locator,
        )

        resource_identifier.additional_properties = d
        return resource_identifier

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.query_workflow_response_result_type_0_item import QueryWorkflowResponseResultType0Item


T = TypeVar("T", bound="QueryWorkflowResponse")


@_attrs_define
class QueryWorkflowResponse:
    """
    Attributes:
        result (list[QueryWorkflowResponseResultType0Item] | None | Unset):
    """

    result: list[QueryWorkflowResponseResultType0Item] | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        result: list[dict[str, Any]] | None | Unset
        if isinstance(self.result, Unset):
            result = UNSET
        elif isinstance(self.result, list):
            result = []
            for result_type_0_item_data in self.result:
                result_type_0_item = result_type_0_item_data.to_dict()
                result.append(result_type_0_item)

        else:
            result = self.result

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if result is not UNSET:
            field_dict["result"] = result

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.query_workflow_response_result_type_0_item import QueryWorkflowResponseResultType0Item

        d = dict(src_dict)

        def _parse_result(data: object) -> list[QueryWorkflowResponseResultType0Item] | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                result_type_0 = []
                _result_type_0 = data
                for result_type_0_item_data in _result_type_0:
                    result_type_0_item = QueryWorkflowResponseResultType0Item.from_dict(result_type_0_item_data)

                    result_type_0.append(result_type_0_item)

                return result_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[QueryWorkflowResponseResultType0Item] | None | Unset, data)

        result = _parse_result(d.pop("result", UNSET))

        query_workflow_response = cls(
            result=result,
        )

        query_workflow_response.additional_properties = d
        return query_workflow_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.resource_type_dto import ResourceTypeDto
from ..types import UNSET, Unset

T = TypeVar("T", bound="ResourceMetadataDto")


@_attrs_define
class ResourceMetadataDto:
    """
    Attributes:
        files_system_rid (str | Unset):
        resource_id (str | Unset):
        uri (str | Unset):
        name (str | Unset):
        type_ (ResourceTypeDto | Unset):
        path (str | Unset):
        extension (None | str | Unset):
        size_in_bytes (int | None | Unset):
        last_modified (datetime.datetime | None | Unset):
        etag (None | str | Unset):
        tags (list[str] | Unset):
    """

    files_system_rid: str | Unset = UNSET
    resource_id: str | Unset = UNSET
    uri: str | Unset = UNSET
    name: str | Unset = UNSET
    type_: ResourceTypeDto | Unset = UNSET
    path: str | Unset = UNSET
    extension: None | str | Unset = UNSET
    size_in_bytes: int | None | Unset = UNSET
    last_modified: datetime.datetime | None | Unset = UNSET
    etag: None | str | Unset = UNSET
    tags: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        files_system_rid = self.files_system_rid

        resource_id = self.resource_id

        uri = self.uri

        name = self.name

        type_: str | Unset = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        path = self.path

        extension: None | str | Unset
        if isinstance(self.extension, Unset):
            extension = UNSET
        else:
            extension = self.extension

        size_in_bytes: int | None | Unset
        if isinstance(self.size_in_bytes, Unset):
            size_in_bytes = UNSET
        else:
            size_in_bytes = self.size_in_bytes

        last_modified: None | str | Unset
        if isinstance(self.last_modified, Unset):
            last_modified = UNSET
        elif isinstance(self.last_modified, datetime.datetime):
            last_modified = self.last_modified.isoformat()
        else:
            last_modified = self.last_modified

        etag: None | str | Unset
        if isinstance(self.etag, Unset):
            etag = UNSET
        else:
            etag = self.etag

        tags: list[str] | Unset = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if files_system_rid is not UNSET:
            field_dict["filesSystemRid"] = files_system_rid
        if resource_id is not UNSET:
            field_dict["resourceId"] = resource_id
        if uri is not UNSET:
            field_dict["uri"] = uri
        if name is not UNSET:
            field_dict["name"] = name
        if type_ is not UNSET:
            field_dict["type"] = type_
        if path is not UNSET:
            field_dict["path"] = path
        if extension is not UNSET:
            field_dict["extension"] = extension
        if size_in_bytes is not UNSET:
            field_dict["sizeInBytes"] = size_in_bytes
        if last_modified is not UNSET:
            field_dict["lastModified"] = last_modified
        if etag is not UNSET:
            field_dict["etag"] = etag
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        files_system_rid = d.pop("filesSystemRid", UNSET)

        resource_id = d.pop("resourceId", UNSET)

        uri = d.pop("uri", UNSET)

        name = d.pop("name", UNSET)

        _type_ = d.pop("type", UNSET)
        type_: ResourceTypeDto | Unset
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = ResourceTypeDto(_type_)

        path = d.pop("path", UNSET)

        def _parse_extension(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        extension = _parse_extension(d.pop("extension", UNSET))

        def _parse_size_in_bytes(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        size_in_bytes = _parse_size_in_bytes(d.pop("sizeInBytes", UNSET))

        def _parse_last_modified(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                last_modified_type_0 = isoparse(data)

                return last_modified_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        last_modified = _parse_last_modified(d.pop("lastModified", UNSET))

        def _parse_etag(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        etag = _parse_etag(d.pop("etag", UNSET))

        tags = cast(list[str], d.pop("tags", UNSET))

        resource_metadata_dto = cls(
            files_system_rid=files_system_rid,
            resource_id=resource_id,
            uri=uri,
            name=name,
            type_=type_,
            path=path,
            extension=extension,
            size_in_bytes=size_in_bytes,
            last_modified=last_modified,
            etag=etag,
            tags=tags,
        )

        resource_metadata_dto.additional_properties = d
        return resource_metadata_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.list_file_system_response_resources import ListFileSystemResponseResources


T = TypeVar("T", bound="ListFileSystemResponse")


@_attrs_define
class ListFileSystemResponse:
    """
    Attributes:
        resources (ListFileSystemResponseResources | Unset):
    """

    resources: ListFileSystemResponseResources | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        resources: dict[str, Any] | Unset = UNSET
        if not isinstance(self.resources, Unset):
            resources = self.resources.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if resources is not UNSET:
            field_dict["resources"] = resources

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.list_file_system_response_resources import ListFileSystemResponseResources

        d = dict(src_dict)
        _resources = d.pop("resources", UNSET)
        resources: ListFileSystemResponseResources | Unset
        if isinstance(_resources, Unset):
            resources = UNSET
        else:
            resources = ListFileSystemResponseResources.from_dict(_resources)

        list_file_system_response = cls(
            resources=resources,
        )

        list_file_system_response.additional_properties = d
        return list_file_system_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto
    from ..models.s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto


T = TypeVar("T", bound="RemoteFileSystemApiDto")


@_attrs_define
class RemoteFileSystemApiDto:
    """
    Attributes:
        rid (str | Unset):
        name (str | Unset):
        description (str | Unset):
        metadata (AzureBlobFileSystemRootMetadataApiDto | S3FileSystemRootMetadataApiDto | Unset):
        connection_rid (str | Unset):
        type_ (str | Unset):
    """

    rid: str | Unset = UNSET
    name: str | Unset = UNSET
    description: str | Unset = UNSET
    metadata: AzureBlobFileSystemRootMetadataApiDto | S3FileSystemRootMetadataApiDto | Unset = UNSET
    connection_rid: str | Unset = UNSET
    type_: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto

        rid = self.rid

        name = self.name

        description = self.description

        metadata: dict[str, Any] | Unset
        if isinstance(self.metadata, Unset):
            metadata = UNSET
        elif isinstance(self.metadata, AzureBlobFileSystemRootMetadataApiDto):
            metadata = self.metadata.to_dict()
        else:
            metadata = self.metadata.to_dict()

        connection_rid = self.connection_rid

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rid is not UNSET:
            field_dict["rid"] = rid
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if connection_rid is not UNSET:
            field_dict["connectionRid"] = connection_rid
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto
        from ..models.s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto

        d = dict(src_dict)
        rid = d.pop("rid", UNSET)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        def _parse_metadata(
            data: object,
        ) -> AzureBlobFileSystemRootMetadataApiDto | S3FileSystemRootMetadataApiDto | Unset:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_file_system_root_metadata_api_dto_type_0 = (
                    AzureBlobFileSystemRootMetadataApiDto.from_dict(data)
                )

                return componentsschemas_file_system_root_metadata_api_dto_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_file_system_root_metadata_api_dto_type_1 = S3FileSystemRootMetadataApiDto.from_dict(data)

            return componentsschemas_file_system_root_metadata_api_dto_type_1

        metadata = _parse_metadata(d.pop("metadata", UNSET))

        connection_rid = d.pop("connectionRid", UNSET)

        type_ = d.pop("type", UNSET)

        remote_file_system_api_dto = cls(
            rid=rid,
            name=name,
            description=description,
            metadata=metadata,
            connection_rid=connection_rid,
            type_=type_,
        )

        remote_file_system_api_dto.additional_properties = d
        return remote_file_system_api_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class IndexingActionStatus(str, Enum):
    EXECUTING = "EXECUTING"
    FAILED = "FAILED"
    PENDING = "PENDING"
    SUCCEEDED = "SUCCEEDED"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MeResponse")


@_attrs_define
class MeResponse:
    """
    Attributes:
        user_id (str | Unset):
        username (str | Unset):
        email (str | Unset):
        first_name (str | Unset):
        last_name (str | Unset):
    """

    user_id: str | Unset = UNSET
    username: str | Unset = UNSET
    email: str | Unset = UNSET
    first_name: str | Unset = UNSET
    last_name: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        username = self.username

        email = self.email

        first_name = self.first_name

        last_name = self.last_name

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user_id is not UNSET:
            field_dict["userId"] = user_id
        if username is not UNSET:
            field_dict["username"] = username
        if email is not UNSET:
            field_dict["email"] = email
        if first_name is not UNSET:
            field_dict["firstName"] = first_name
        if last_name is not UNSET:
            field_dict["lastName"] = last_name

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId", UNSET)

        username = d.pop("username", UNSET)

        email = d.pop("email", UNSET)

        first_name = d.pop("firstName", UNSET)

        last_name = d.pop("lastName", UNSET)

        me_response = cls(
            user_id=user_id,
            username=username,
            email=email,
            first_name=first_name,
            last_name=last_name,
        )

        me_response.additional_properties = d
        return me_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.managed_file_system_api_dto import ManagedFileSystemApiDto
    from ..models.remote_file_system_api_dto import RemoteFileSystemApiDto


T = TypeVar("T", bound="ListAllFileSystemsResponseFileSystems")


@_attrs_define
class ListAllFileSystemsResponseFileSystems:
    """ """

    additional_properties: dict[str, ManagedFileSystemApiDto | RemoteFileSystemApiDto] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> dict[str, Any]:
        from ..models.remote_file_system_api_dto import RemoteFileSystemApiDto

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            if isinstance(prop, RemoteFileSystemApiDto):
                field_dict[prop_name] = prop.to_dict()
            else:
                field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.managed_file_system_api_dto import ManagedFileSystemApiDto
        from ..models.remote_file_system_api_dto import RemoteFileSystemApiDto

        d = dict(src_dict)
        list_all_file_systems_response_file_systems = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():

            def _parse_additional_property(data: object) -> ManagedFileSystemApiDto | RemoteFileSystemApiDto:
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    componentsschemas_file_system_api_dto_type_0 = RemoteFileSystemApiDto.from_dict(data)

                    return componentsschemas_file_system_api_dto_type_0
                except (TypeError, ValueError, AttributeError, KeyError):
                    pass
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_file_system_api_dto_type_1 = ManagedFileSystemApiDto.from_dict(data)

                return componentsschemas_file_system_api_dto_type_1

            additional_property = _parse_additional_property(prop_dict)

            additional_properties[prop_name] = additional_property

        list_all_file_systems_response_file_systems.additional_properties = additional_properties
        return list_all_file_systems_response_file_systems

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> ManagedFileSystemApiDto | RemoteFileSystemApiDto:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: ManagedFileSystemApiDto | RemoteFileSystemApiDto) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_indexing_task_request_settings import CreateIndexingTaskRequestSettings


T = TypeVar("T", bound="CreateIndexingTaskRequest")


@_attrs_define
class CreateIndexingTaskRequest:
    """
    Attributes:
        indexer_rid (str):
        folder_uri (str | Unset):
        namespace (str | Unset):
        target_minimum_version (int | Unset):
        settings (CreateIndexingTaskRequestSettings | Unset):
    """

    indexer_rid: str
    folder_uri: str | Unset = UNSET
    namespace: str | Unset = UNSET
    target_minimum_version: int | Unset = UNSET
    settings: CreateIndexingTaskRequestSettings | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        indexer_rid = self.indexer_rid

        folder_uri = self.folder_uri

        namespace = self.namespace

        target_minimum_version = self.target_minimum_version

        settings: dict[str, Any] | Unset = UNSET
        if not isinstance(self.settings, Unset):
            settings = self.settings.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "indexerRid": indexer_rid,
            }
        )
        if folder_uri is not UNSET:
            field_dict["folderUri"] = folder_uri
        if namespace is not UNSET:
            field_dict["namespace"] = namespace
        if target_minimum_version is not UNSET:
            field_dict["targetMinimumVersion"] = target_minimum_version
        if settings is not UNSET:
            field_dict["settings"] = settings

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_indexing_task_request_settings import CreateIndexingTaskRequestSettings

        d = dict(src_dict)
        indexer_rid = d.pop("indexerRid")

        folder_uri = d.pop("folderUri", UNSET)

        namespace = d.pop("namespace", UNSET)

        target_minimum_version = d.pop("targetMinimumVersion", UNSET)

        _settings = d.pop("settings", UNSET)
        settings: CreateIndexingTaskRequestSettings | Unset
        if isinstance(_settings, Unset):
            settings = UNSET
        else:
            settings = CreateIndexingTaskRequestSettings.from_dict(_settings)

        create_indexing_task_request = cls(
            indexer_rid=indexer_rid,
            folder_uri=folder_uri,
            namespace=namespace,
            target_minimum_version=target_minimum_version,
            settings=settings,
        )

        create_indexing_task_request.additional_properties = d
        return create_indexing_task_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.update_indexing_schedule_request import UpdateIndexingScheduleRequest
from ...models.update_indexing_schedule_response import UpdateIndexingScheduleResponse
from ...types import Response


def _get_kwargs(
    schedule_rid: str,
    *,
    body: UpdateIndexingScheduleRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "patch",
        "url": "/api/v1/indexing/schedules/{schedule_rid}".format(
            schedule_rid=quote(str(schedule_rid), safe=""),
        ),
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | UpdateIndexingScheduleResponse | None:
    if response.status_code == 200:
        response_200 = UpdateIndexingScheduleResponse.from_dict(response.json())

        return response_200

    if response.status_code == 400:
        response_400 = cast(Any, None)
        return response_400

    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404

    if response.status_code == 409:
        response_409 = cast(Any, None)
        return response_409

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | UpdateIndexingScheduleResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    schedule_rid: str,
    *,
    client: AuthenticatedClient | Client,
    body: UpdateIndexingScheduleRequest,
) -> Response[Any | UpdateIndexingScheduleResponse]:
    """Update an indexing schedule

     Updates specific fields of an existing schedule. Only provided fields will be updated.

    Args:
        schedule_rid (str):
        body (UpdateIndexingScheduleRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | UpdateIndexingScheduleResponse]
    """

    kwargs = _get_kwargs(
        schedule_rid=schedule_rid,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    schedule_rid: str,
    *,
    client: AuthenticatedClient | Client,
    body: UpdateIndexingScheduleRequest,
) -> Any | UpdateIndexingScheduleResponse | None:
    """Update an indexing schedule

     Updates specific fields of an existing schedule. Only provided fields will be updated.

    Args:
        schedule_rid (str):
        body (UpdateIndexingScheduleRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | UpdateIndexingScheduleResponse
    """

    return sync_detailed(
        schedule_rid=schedule_rid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    schedule_rid: str,
    *,
    client: AuthenticatedClient | Client,
    body: UpdateIndexingScheduleRequest,
) -> Response[Any | UpdateIndexingScheduleResponse]:
    """Update an indexing schedule

     Updates specific fields of an existing schedule. Only provided fields will be updated.

    Args:
        schedule_rid (str):
        body (UpdateIndexingScheduleRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | UpdateIndexingScheduleResponse]
    """

    kwargs = _get_kwargs(
        schedule_rid=schedule_rid,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    schedule_rid: str,
    *,
    client: AuthenticatedClient | Client,
    body: UpdateIndexingScheduleRequest,
) -> Any | UpdateIndexingScheduleResponse | None:
    """Update an indexing schedule

     Updates specific fields of an existing schedule. Only provided fields will be updated.

    Args:
        schedule_rid (str):
        body (UpdateIndexingScheduleRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | UpdateIndexingScheduleResponse
    """

    return (
        await asyncio_detailed(
            schedule_rid=schedule_rid,
            client=client,
            body=body,
        )
    ).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.indexing_action_dto import IndexingActionDto


T = TypeVar("T", bound="ListIndexingActionsResponse")


@_attrs_define
class ListIndexingActionsResponse:
    """
    Attributes:
        actions (list[IndexingActionDto] | Unset):
        total_actions (int | Unset):
        next_offset (int | None | Unset):
        pending_count (int | Unset):
        executing_count (int | Unset):
        succeeded_count (int | Unset):
        failed_count (int | Unset):
        index_count (int | Unset):
        delete_count (int | Unset):
    """

    actions: list[IndexingActionDto] | Unset = UNSET
    total_actions: int | Unset = UNSET
    next_offset: int | None | Unset = UNSET
    pending_count: int | Unset = UNSET
    executing_count: int | Unset = UNSET
    succeeded_count: int | Unset = UNSET
    failed_count: int | Unset = UNSET
    index_count: int | Unset = UNSET
    delete_count: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        actions: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.actions, Unset):
            actions = []
            for actions_item_data in self.actions:
                actions_item = actions_item_data.to_dict()
                actions.append(actions_item)

        total_actions = self.total_actions

        next_offset: int | None | Unset
        if isinstance(self.next_offset, Unset):
            next_offset = UNSET
        else:
            next_offset = self.next_offset

        pending_count = self.pending_count

        executing_count = self.executing_count

        succeeded_count = self.succeeded_count

        failed_count = self.failed_count

        index_count = self.index_count

        delete_count = self.delete_count

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if actions is not UNSET:
            field_dict["actions"] = actions
        if total_actions is not UNSET:
            field_dict["totalActions"] = total_actions
        if next_offset is not UNSET:
            field_dict["nextOffset"] = next_offset
        if pending_count is not UNSET:
            field_dict["pendingCount"] = pending_count
        if executing_count is not UNSET:
            field_dict["executingCount"] = executing_count
        if succeeded_count is not UNSET:
            field_dict["succeededCount"] = succeeded_count
        if failed_count is not UNSET:
            field_dict["failedCount"] = failed_count
        if index_count is not UNSET:
            field_dict["indexCount"] = index_count
        if delete_count is not UNSET:
            field_dict["deleteCount"] = delete_count

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.indexing_action_dto import IndexingActionDto

        d = dict(src_dict)
        _actions = d.pop("actions", UNSET)
        actions: list[IndexingActionDto] | Unset = UNSET
        if _actions is not UNSET:
            actions = []
            for actions_item_data in _actions:
                actions_item = IndexingActionDto.from_dict(actions_item_data)

                actions.append(actions_item)

        total_actions = d.pop("totalActions", UNSET)

        def _parse_next_offset(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        next_offset = _parse_next_offset(d.pop("nextOffset", UNSET))

        pending_count = d.pop("pendingCount", UNSET)

        executing_count = d.pop("executingCount", UNSET)

        succeeded_count = d.pop("succeededCount", UNSET)

        failed_count = d.pop("failedCount", UNSET)

        index_count = d.pop("indexCount", UNSET)

        delete_count = d.pop("deleteCount", UNSET)

        list_indexing_actions_response = cls(
            actions=actions,
            total_actions=total_actions,
            next_offset=next_offset,
            pending_count=pending_count,
            executing_count=executing_count,
            succeeded_count=succeeded_count,
            failed_count=failed_count,
            index_count=index_count,
            delete_count=delete_count,
        )

        list_indexing_actions_response.additional_properties = d
        return list_indexing_actions_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.send_workflow_signal_request_inputs import SendWorkflowSignalRequestInputs


T = TypeVar("T", bound="SendWorkflowSignalRequest")


@_attrs_define
class SendWorkflowSignalRequest:
    """
    Attributes:
        inputs (SendWorkflowSignalRequestInputs | Unset):
    """

    inputs: SendWorkflowSignalRequestInputs | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        inputs: dict[str, Any] | Unset = UNSET
        if not isinstance(self.inputs, Unset):
            inputs = self.inputs.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if inputs is not UNSET:
            field_dict["inputs"] = inputs

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.send_workflow_signal_request_inputs import SendWorkflowSignalRequestInputs

        d = dict(src_dict)
        _inputs = d.pop("inputs", UNSET)
        inputs: SendWorkflowSignalRequestInputs | Unset
        if isinstance(_inputs, Unset):
            inputs = UNSET
        else:
            inputs = SendWorkflowSignalRequestInputs.from_dict(_inputs)

        send_workflow_signal_request = cls(
            inputs=inputs,
        )

        send_workflow_signal_request.additional_properties = d
        return send_workflow_signal_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="IntervalTrigger")


@_attrs_define
class IntervalTrigger:
    """
    Attributes:
        interval (str):
        start_time (datetime.datetime | None | Unset): Optional start time for first execution
        type_ (str | Unset):
    """

    interval: str
    start_time: datetime.datetime | None | Unset = UNSET
    type_: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        interval = self.interval

        start_time: None | str | Unset
        if isinstance(self.start_time, Unset):
            start_time = UNSET
        elif isinstance(self.start_time, datetime.datetime):
            start_time = self.start_time.isoformat()
        else:
            start_time = self.start_time

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "interval": interval,
            }
        )
        if start_time is not UNSET:
            field_dict["startTime"] = start_time
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        interval = d.pop("interval")

        def _parse_start_time(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                start_time_type_0 = isoparse(data)

                return start_time_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        start_time = _parse_start_time(d.pop("startTime", UNSET))

        type_ = d.pop("type", UNSET)

        interval_trigger = cls(
            interval=interval,
            start_time=start_time,
            type_=type_,
        )

        interval_trigger.additional_properties = d
        return interval_trigger

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.schema_location import SchemaLocation
    from ..models.schema_unprocessed_properties import SchemaUnprocessedProperties


T = TypeVar("T", bound="Schema")


@_attrs_define
class Schema:
    """
    Attributes:
        title (str | Unset):
        description (str | Unset):
        id (str | Unset):
        schema_location (str | Unset):
        location (SchemaLocation | Unset):
        default_value (Any | Unset):
        nullable (bool | Unset):
        read_only (bool | Unset):
        write_only (bool | Unset):
        unprocessed_properties (SchemaUnprocessedProperties | Unset):
    """

    title: str | Unset = UNSET
    description: str | Unset = UNSET
    id: str | Unset = UNSET
    schema_location: str | Unset = UNSET
    location: SchemaLocation | Unset = UNSET
    default_value: Any | Unset = UNSET
    nullable: bool | Unset = UNSET
    read_only: bool | Unset = UNSET
    write_only: bool | Unset = UNSET
    unprocessed_properties: SchemaUnprocessedProperties | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        title = self.title

        description = self.description

        id = self.id

        schema_location = self.schema_location

        location: dict[str, Any] | Unset = UNSET
        if not isinstance(self.location, Unset):
            location = self.location.to_dict()

        default_value = self.default_value

        nullable = self.nullable

        read_only = self.read_only

        write_only = self.write_only

        unprocessed_properties: dict[str, Any] | Unset = UNSET
        if not isinstance(self.unprocessed_properties, Unset):
            unprocessed_properties = self.unprocessed_properties.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if id is not UNSET:
            field_dict["id"] = id
        if schema_location is not UNSET:
            field_dict["schemaLocation"] = schema_location
        if location is not UNSET:
            field_dict["location"] = location
        if default_value is not UNSET:
            field_dict["defaultValue"] = default_value
        if nullable is not UNSET:
            field_dict["nullable"] = nullable
        if read_only is not UNSET:
            field_dict["readOnly"] = read_only
        if write_only is not UNSET:
            field_dict["writeOnly"] = write_only
        if unprocessed_properties is not UNSET:
            field_dict["unprocessedProperties"] = unprocessed_properties

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.schema_location import SchemaLocation
        from ..models.schema_unprocessed_properties import SchemaUnprocessedProperties

        d = dict(src_dict)
        title = d.pop("title", UNSET)

        description = d.pop("description", UNSET)

        id = d.pop("id", UNSET)

        schema_location = d.pop("schemaLocation", UNSET)

        _location = d.pop("location", UNSET)
        location: SchemaLocation | Unset
        if isinstance(_location, Unset):
            location = UNSET
        else:
            location = SchemaLocation.from_dict(_location)

        default_value = d.pop("defaultValue", UNSET)

        nullable = d.pop("nullable", UNSET)

        read_only = d.pop("readOnly", UNSET)

        write_only = d.pop("writeOnly", UNSET)

        _unprocessed_properties = d.pop("unprocessedProperties", UNSET)
        unprocessed_properties: SchemaUnprocessedProperties | Unset
        if isinstance(_unprocessed_properties, Unset):
            unprocessed_properties = UNSET
        else:
            unprocessed_properties = SchemaUnprocessedProperties.from_dict(_unprocessed_properties)

        schema = cls(
            title=title,
            description=description,
            id=id,
            schema_location=schema_location,
            location=location,
            default_value=default_value,
            nullable=nullable,
            read_only=read_only,
            write_only=write_only,
            unprocessed_properties=unprocessed_properties,
        )

        schema.additional_properties = d
        return schema

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.action_type import ActionType
from ..models.indexing_action_status import IndexingActionStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="IndexingActionDto")


@_attrs_define
class IndexingActionDto:
    """
    Attributes:
        action_type (ActionType | Unset):
        target_uri (str | Unset):
        target_minimum_version (int | Unset):
        status (IndexingActionStatus | Unset):
        error_message (None | str | Unset):
        executed_at (datetime.datetime | None | Unset):
        reason (str | Unset):
    """

    action_type: ActionType | Unset = UNSET
    target_uri: str | Unset = UNSET
    target_minimum_version: int | Unset = UNSET
    status: IndexingActionStatus | Unset = UNSET
    error_message: None | str | Unset = UNSET
    executed_at: datetime.datetime | None | Unset = UNSET
    reason: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        action_type: str | Unset = UNSET
        if not isinstance(self.action_type, Unset):
            action_type = self.action_type.value

        target_uri = self.target_uri

        target_minimum_version = self.target_minimum_version

        status: str | Unset = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        error_message: None | str | Unset
        if isinstance(self.error_message, Unset):
            error_message = UNSET
        else:
            error_message = self.error_message

        executed_at: None | str | Unset
        if isinstance(self.executed_at, Unset):
            executed_at = UNSET
        elif isinstance(self.executed_at, datetime.datetime):
            executed_at = self.executed_at.isoformat()
        else:
            executed_at = self.executed_at

        reason = self.reason

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if action_type is not UNSET:
            field_dict["actionType"] = action_type
        if target_uri is not UNSET:
            field_dict["targetUri"] = target_uri
        if target_minimum_version is not UNSET:
            field_dict["targetMinimumVersion"] = target_minimum_version
        if status is not UNSET:
            field_dict["status"] = status
        if error_message is not UNSET:
            field_dict["errorMessage"] = error_message
        if executed_at is not UNSET:
            field_dict["executedAt"] = executed_at
        if reason is not UNSET:
            field_dict["reason"] = reason

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _action_type = d.pop("actionType", UNSET)
        action_type: ActionType | Unset
        if isinstance(_action_type, Unset):
            action_type = UNSET
        else:
            action_type = ActionType(_action_type)

        target_uri = d.pop("targetUri", UNSET)

        target_minimum_version = d.pop("targetMinimumVersion", UNSET)

        _status = d.pop("status", UNSET)
        status: IndexingActionStatus | Unset
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = IndexingActionStatus(_status)

        def _parse_error_message(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        error_message = _parse_error_message(d.pop("errorMessage", UNSET))

        def _parse_executed_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                executed_at_type_0 = isoparse(data)

                return executed_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        executed_at = _parse_executed_at(d.pop("executedAt", UNSET))

        reason = d.pop("reason", UNSET)

        indexing_action_dto = cls(
            action_type=action_type,
            target_uri=target_uri,
            target_minimum_version=target_minimum_version,
            status=status,
            error_message=error_message,
            executed_at=executed_at,
            reason=reason,
        )

        indexing_action_dto.additional_properties = d
        return indexing_action_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.tag_info import TagInfo


T = TypeVar("T", bound="ListTagsResponse")


@_attrs_define
class ListTagsResponse:
    """
    Attributes:
        tags (list[TagInfo] | Unset):
    """

    tags: list[TagInfo] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        tags: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.tags, Unset):
            tags = []
            for tags_item_data in self.tags:
                tags_item = tags_item_data.to_dict()
                tags.append(tags_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tag_info import TagInfo

        d = dict(src_dict)
        _tags = d.pop("tags", UNSET)
        tags: list[TagInfo] | Unset = UNSET
        if _tags is not UNSET:
            tags = []
            for tags_item_data in _tags:
                tags_item = TagInfo.from_dict(tags_item_data)

                tags.append(tags_item)

        list_tags_response = cls(
            tags=tags,
        )

        list_tags_response.additional_properties = d
        return list_tags_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.progress_event_payload import ProgressEventPayload


T = TypeVar("T", bound="ProgressEvent")


@_attrs_define
class ProgressEvent:
    """
    Attributes:
        sequence (int | Unset):
        payload (ProgressEventPayload | Unset):
        created_at (datetime.datetime | Unset):
        type_ (str | Unset):
    """

    sequence: int | Unset = UNSET
    payload: ProgressEventPayload | Unset = UNSET
    created_at: datetime.datetime | Unset = UNSET
    type_: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        sequence = self.sequence

        payload: dict[str, Any] | Unset = UNSET
        if not isinstance(self.payload, Unset):
            payload = self.payload.to_dict()

        created_at: str | Unset = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        type_ = self.type_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sequence is not UNSET:
            field_dict["sequence"] = sequence
        if payload is not UNSET:
            field_dict["payload"] = payload
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.progress_event_payload import ProgressEventPayload

        d = dict(src_dict)
        sequence = d.pop("sequence", UNSET)

        _payload = d.pop("payload", UNSET)
        payload: ProgressEventPayload | Unset
        if isinstance(_payload, Unset):
            payload = UNSET
        else:
            payload = ProgressEventPayload.from_dict(_payload)

        _created_at = d.pop("createdAt", UNSET)
        created_at: datetime.datetime | Unset
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        type_ = d.pop("type", UNSET)

        progress_event = cls(
            sequence=sequence,
            payload=payload,
            created_at=created_at,
            type_=type_,
        )

        progress_event.additional_properties = d
        return progress_event

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.cron_trigger import CronTrigger
    from ..models.indexing_schedule_dto_indexing_settings import IndexingScheduleDtoIndexingSettings
    from ..models.interval_trigger import IntervalTrigger
    from ..models.on_upload_trigger import OnUploadTrigger


T = TypeVar("T", bound="IndexingScheduleDto")


@_attrs_define
class IndexingScheduleDto:
    """
    Attributes:
        schedule_rid (str | Unset):
        name (str | Unset):
        description (str | Unset):
        indexer_rid (str | Unset):
        target_uri (str | Unset):
        namespace (str | Unset):
        target_minimum_version (int | Unset):
        indexing_settings (IndexingScheduleDtoIndexingSettings | Unset):
        trigger (CronTrigger | IntervalTrigger | OnUploadTrigger | Unset):
        enabled (bool | Unset):
        created_at (datetime.datetime | Unset):
        updated_at (datetime.datetime | Unset):
        last_executed_at (datetime.datetime | None | Unset):
        next_execution_at (datetime.datetime | None | Unset):
    """

    schedule_rid: str | Unset = UNSET
    name: str | Unset = UNSET
    description: str | Unset = UNSET
    indexer_rid: str | Unset = UNSET
    target_uri: str | Unset = UNSET
    namespace: str | Unset = UNSET
    target_minimum_version: int | Unset = UNSET
    indexing_settings: IndexingScheduleDtoIndexingSettings | Unset = UNSET
    trigger: CronTrigger | IntervalTrigger | OnUploadTrigger | Unset = UNSET
    enabled: bool | Unset = UNSET
    created_at: datetime.datetime | Unset = UNSET
    updated_at: datetime.datetime | Unset = UNSET
    last_executed_at: datetime.datetime | None | Unset = UNSET
    next_execution_at: datetime.datetime | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.cron_trigger import CronTrigger
        from ..models.on_upload_trigger import OnUploadTrigger

        schedule_rid = self.schedule_rid

        name = self.name

        description = self.description

        indexer_rid = self.indexer_rid

        target_uri = self.target_uri

        namespace = self.namespace

        target_minimum_version = self.target_minimum_version

        indexing_settings: dict[str, Any] | Unset = UNSET
        if not isinstance(self.indexing_settings, Unset):
            indexing_settings = self.indexing_settings.to_dict()

        trigger: dict[str, Any] | Unset
        if isinstance(self.trigger, Unset):
            trigger = UNSET
        elif isinstance(self.trigger, OnUploadTrigger):
            trigger = self.trigger.to_dict()
        elif isinstance(self.trigger, CronTrigger):
            trigger = self.trigger.to_dict()
        else:
            trigger = self.trigger.to_dict()

        enabled = self.enabled

        created_at: str | Unset = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: str | Unset = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        last_executed_at: None | str | Unset
        if isinstance(self.last_executed_at, Unset):
            last_executed_at = UNSET
        elif isinstance(self.last_executed_at, datetime.datetime):
            last_executed_at = self.last_executed_at.isoformat()
        else:
            last_executed_at = self.last_executed_at

        next_execution_at: None | str | Unset
        if isinstance(self.next_execution_at, Unset):
            next_execution_at = UNSET
        elif isinstance(self.next_execution_at, datetime.datetime):
            next_execution_at = self.next_execution_at.isoformat()
        else:
            next_execution_at = self.next_execution_at

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schedule_rid is not UNSET:
            field_dict["scheduleRid"] = schedule_rid
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if indexer_rid is not UNSET:
            field_dict["indexerRid"] = indexer_rid
        if target_uri is not UNSET:
            field_dict["targetUri"] = target_uri
        if namespace is not UNSET:
            field_dict["namespace"] = namespace
        if target_minimum_version is not UNSET:
            field_dict["targetMinimumVersion"] = target_minimum_version
        if indexing_settings is not UNSET:
            field_dict["indexingSettings"] = indexing_settings
        if trigger is not UNSET:
            field_dict["trigger"] = trigger
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if last_executed_at is not UNSET:
            field_dict["lastExecutedAt"] = last_executed_at
        if next_execution_at is not UNSET:
            field_dict["nextExecutionAt"] = next_execution_at

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.cron_trigger import CronTrigger
        from ..models.indexing_schedule_dto_indexing_settings import IndexingScheduleDtoIndexingSettings
        from ..models.interval_trigger import IntervalTrigger
        from ..models.on_upload_trigger import OnUploadTrigger

        d = dict(src_dict)
        schedule_rid = d.pop("scheduleRid", UNSET)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        indexer_rid = d.pop("indexerRid", UNSET)

        target_uri = d.pop("targetUri", UNSET)

        namespace = d.pop("namespace", UNSET)

        target_minimum_version = d.pop("targetMinimumVersion", UNSET)

        _indexing_settings = d.pop("indexingSettings", UNSET)
        indexing_settings: IndexingScheduleDtoIndexingSettings | Unset
        if isinstance(_indexing_settings, Unset):
            indexing_settings = UNSET
        else:
            indexing_settings = IndexingScheduleDtoIndexingSettings.from_dict(_indexing_settings)

        def _parse_trigger(data: object) -> CronTrigger | IntervalTrigger | OnUploadTrigger | Unset:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schedule_trigger_type_0 = OnUploadTrigger.from_dict(data)

                return componentsschemas_schedule_trigger_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schedule_trigger_type_1 = CronTrigger.from_dict(data)

                return componentsschemas_schedule_trigger_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_schedule_trigger_type_2 = IntervalTrigger.from_dict(data)

            return componentsschemas_schedule_trigger_type_2

        trigger = _parse_trigger(d.pop("trigger", UNSET))

        enabled = d.pop("enabled", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: datetime.datetime | Unset
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: datetime.datetime | Unset
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        def _parse_last_executed_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                last_executed_at_type_0 = isoparse(data)

                return last_executed_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        last_executed_at = _parse_last_executed_at(d.pop("lastExecutedAt", UNSET))

        def _parse_next_execution_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                next_execution_at_type_0 = isoparse(data)

                return next_execution_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        next_execution_at = _parse_next_execution_at(d.pop("nextExecutionAt", UNSET))

        indexing_schedule_dto = cls(
            schedule_rid=schedule_rid,
            name=name,
            description=description,
            indexer_rid=indexer_rid,
            target_uri=target_uri,
            namespace=namespace,
            target_minimum_version=target_minimum_version,
            indexing_settings=indexing_settings,
            trigger=trigger,
            enabled=enabled,
            created_at=created_at,
            updated_at=updated_at,
            last_executed_at=last_executed_at,
            next_execution_at=next_execution_at,
        )

        indexing_schedule_dto.additional_properties = d
        return indexing_schedule_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.indexing_task_dto_settings import IndexingTaskDtoSettings
    from ..models.indexing_task_status import IndexingTaskStatus


T = TypeVar("T", bound="IndexingTaskDto")


@_attrs_define
class IndexingTaskDto:
    """
    Attributes:
        task_rid (str | Unset):
        indexer_rid (str | Unset):
        folder_uri (str | Unset):
        namespace (str | Unset):
        target_minimum_version (int | Unset):
        settings (IndexingTaskDtoSettings | Unset):
        created_at (datetime.datetime | Unset):
        status (IndexingTaskStatus | Unset):
    """

    task_rid: str | Unset = UNSET
    indexer_rid: str | Unset = UNSET
    folder_uri: str | Unset = UNSET
    namespace: str | Unset = UNSET
    target_minimum_version: int | Unset = UNSET
    settings: IndexingTaskDtoSettings | Unset = UNSET
    created_at: datetime.datetime | Unset = UNSET
    status: IndexingTaskStatus | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        task_rid = self.task_rid

        indexer_rid = self.indexer_rid

        folder_uri = self.folder_uri

        namespace = self.namespace

        target_minimum_version = self.target_minimum_version

        settings: dict[str, Any] | Unset = UNSET
        if not isinstance(self.settings, Unset):
            settings = self.settings.to_dict()

        created_at: str | Unset = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        status: dict[str, Any] | Unset = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if task_rid is not UNSET:
            field_dict["taskRid"] = task_rid
        if indexer_rid is not UNSET:
            field_dict["indexerRid"] = indexer_rid
        if folder_uri is not UNSET:
            field_dict["folderUri"] = folder_uri
        if namespace is not UNSET:
            field_dict["namespace"] = namespace
        if target_minimum_version is not UNSET:
            field_dict["targetMinimumVersion"] = target_minimum_version
        if settings is not UNSET:
            field_dict["settings"] = settings
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.indexing_task_dto_settings import IndexingTaskDtoSettings
        from ..models.indexing_task_status import IndexingTaskStatus

        d = dict(src_dict)
        task_rid = d.pop("taskRid", UNSET)

        indexer_rid = d.pop("indexerRid", UNSET)

        folder_uri = d.pop("folderUri", UNSET)

        namespace = d.pop("namespace", UNSET)

        target_minimum_version = d.pop("targetMinimumVersion", UNSET)

        _settings = d.pop("settings", UNSET)
        settings: IndexingTaskDtoSettings | Unset
        if isinstance(_settings, Unset):
            settings = UNSET
        else:
            settings = IndexingTaskDtoSettings.from_dict(_settings)

        _created_at = d.pop("createdAt", UNSET)
        created_at: datetime.datetime | Unset
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _status = d.pop("status", UNSET)
        status: IndexingTaskStatus | Unset
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = IndexingTaskStatus.from_dict(_status)

        indexing_task_dto = cls(
            task_rid=task_rid,
            indexer_rid=indexer_rid,
            folder_uri=folder_uri,
            namespace=namespace,
            target_minimum_version=target_minimum_version,
            settings=settings,
            created_at=created_at,
            status=status,
        )

        indexing_task_dto.additional_properties = d
        return indexing_task_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.workflow_event import WorkflowEvent


T = TypeVar("T", bound="GetWorkflowEventsResponse")


@_attrs_define
class GetWorkflowEventsResponse:
    """
    Attributes:
        events (list[WorkflowEvent] | Unset):
        next_page_token (None | str | Unset):
    """

    events: list[WorkflowEvent] | Unset = UNSET
    next_page_token: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        events: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.events, Unset):
            events = []
            for events_item_data in self.events:
                events_item = events_item_data.to_dict()
                events.append(events_item)

        next_page_token: None | str | Unset
        if isinstance(self.next_page_token, Unset):
            next_page_token = UNSET
        else:
            next_page_token = self.next_page_token

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if events is not UNSET:
            field_dict["events"] = events
        if next_page_token is not UNSET:
            field_dict["nextPageToken"] = next_page_token

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.workflow_event import WorkflowEvent

        d = dict(src_dict)
        _events = d.pop("events", UNSET)
        events: list[WorkflowEvent] | Unset = UNSET
        if _events is not UNSET:
            events = []
            for events_item_data in _events:
                events_item = WorkflowEvent.from_dict(events_item_data)

                events.append(events_item)

        def _parse_next_page_token(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        next_page_token = _parse_next_page_token(d.pop("nextPageToken", UNSET))

        get_workflow_events_response = cls(
            events=events,
            next_page_token=next_page_token,
        )

        get_workflow_events_response.additional_properties = d
        return get_workflow_events_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageDetectionBoxApiDto")


@_attrs_define
class ImageDetectionBoxApiDto:
    """
    Attributes:
        x_min (int | Unset):
        y_min (int | Unset):
        x_max (int | Unset):
        y_max (int | Unset):
        label (str | Unset):
        confidence (float | Unset):
    """

    x_min: int | Unset = UNSET
    y_min: int | Unset = UNSET
    x_max: int | Unset = UNSET
    y_max: int | Unset = UNSET
    label: str | Unset = UNSET
    confidence: float | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        x_min = self.x_min

        y_min = self.y_min

        x_max = self.x_max

        y_max = self.y_max

        label = self.label

        confidence = self.confidence

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if x_min is not UNSET:
            field_dict["xMin"] = x_min
        if y_min is not UNSET:
            field_dict["yMin"] = y_min
        if x_max is not UNSET:
            field_dict["xMax"] = x_max
        if y_max is not UNSET:
            field_dict["yMax"] = y_max
        if label is not UNSET:
            field_dict["label"] = label
        if confidence is not UNSET:
            field_dict["confidence"] = confidence

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        x_min = d.pop("xMin", UNSET)

        y_min = d.pop("yMin", UNSET)

        x_max = d.pop("xMax", UNSET)

        y_max = d.pop("yMax", UNSET)

        label = d.pop("label", UNSET)

        confidence = d.pop("confidence", UNSET)

        image_detection_box_api_dto = cls(
            x_min=x_min,
            y_min=y_min,
            x_max=x_max,
            y_max=y_max,
            label=label,
            confidence=confidence,
        )

        image_detection_box_api_dto.additional_properties = d
        return image_detection_box_api_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.info_event import InfoEvent
    from ..models.progress_event import ProgressEvent
    from ..models.request_for_input_event import RequestForInputEvent


T = TypeVar("T", bound="GetWorkerEventsResponse")


@_attrs_define
class GetWorkerEventsResponse:
    """
    Attributes:
        events (list[InfoEvent | ProgressEvent | RequestForInputEvent] | Unset):
    """

    events: list[InfoEvent | ProgressEvent | RequestForInputEvent] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.info_event import InfoEvent
        from ..models.progress_event import ProgressEvent

        events: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.events, Unset):
            events = []
            for events_item_data in self.events:
                events_item: dict[str, Any]
                if isinstance(events_item_data, InfoEvent):
                    events_item = events_item_data.to_dict()
                elif isinstance(events_item_data, ProgressEvent):
                    events_item = events_item_data.to_dict()
                else:
                    events_item = events_item_data.to_dict()

                events.append(events_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if events is not UNSET:
            field_dict["events"] = events

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.info_event import InfoEvent
        from ..models.progress_event import ProgressEvent
        from ..models.request_for_input_event import RequestForInputEvent

        d = dict(src_dict)
        _events = d.pop("events", UNSET)
        events: list[InfoEvent | ProgressEvent | RequestForInputEvent] | Unset = UNSET
        if _events is not UNSET:
            events = []
            for events_item_data in _events:

                def _parse_events_item(data: object) -> InfoEvent | ProgressEvent | RequestForInputEvent:
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_worker_event_type_0 = InfoEvent.from_dict(data)

                        return componentsschemas_worker_event_type_0
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    try:
                        if not isinstance(data, dict):
                            raise TypeError()
                        componentsschemas_worker_event_type_1 = ProgressEvent.from_dict(data)

                        return componentsschemas_worker_event_type_1
                    except (TypeError, ValueError, AttributeError, KeyError):
                        pass
                    if not isinstance(data, dict):
                        raise TypeError()
                    componentsschemas_worker_event_type_2 = RequestForInputEvent.from_dict(data)

                    return componentsschemas_worker_event_type_2

                events_item = _parse_events_item(events_item_data)

                events.append(events_item)

        get_worker_events_response = cls(
            events=events,
        )

        get_worker_events_response.additional_properties = d
        return get_worker_events_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.create_indexing_schedule_request_indexing_settings import (
        CreateIndexingScheduleRequestIndexingSettings,
    )
    from ..models.cron_trigger import CronTrigger
    from ..models.interval_trigger import IntervalTrigger
    from ..models.on_upload_trigger import OnUploadTrigger


T = TypeVar("T", bound="CreateIndexingScheduleRequest")


@_attrs_define
class CreateIndexingScheduleRequest:
    """
    Attributes:
        name (str): Display name for the schedule Example: Daily CSV indexing.
        indexer_rid (str): RID of the indexer to use Example: ri.indexer..instance.indexer-csv-processor.
        target_uri (str): URI of folder or filesystem to index Example: prtc://ri.perceptic..instance.fs-data-
            lake/documents.
        namespace (str): Namespace for indexing Example: production.
        trigger (CronTrigger | IntervalTrigger | OnUploadTrigger):
        description (str | Unset): Optional description of the schedule's purpose
        target_minimum_version (int | Unset): Minimum indexer version required Example: 1.
        indexing_settings (CreateIndexingScheduleRequestIndexingSettings | Unset): Indexer-specific settings
        enabled (bool | Unset): Whether the schedule is enabled Example: True.
    """

    name: str
    indexer_rid: str
    target_uri: str
    namespace: str
    trigger: CronTrigger | IntervalTrigger | OnUploadTrigger
    description: str | Unset = UNSET
    target_minimum_version: int | Unset = UNSET
    indexing_settings: CreateIndexingScheduleRequestIndexingSettings | Unset = UNSET
    enabled: bool | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.cron_trigger import CronTrigger
        from ..models.on_upload_trigger import OnUploadTrigger

        name = self.name

        indexer_rid = self.indexer_rid

        target_uri = self.target_uri

        namespace = self.namespace

        trigger: dict[str, Any]
        if isinstance(self.trigger, OnUploadTrigger):
            trigger = self.trigger.to_dict()
        elif isinstance(self.trigger, CronTrigger):
            trigger = self.trigger.to_dict()
        else:
            trigger = self.trigger.to_dict()

        description = self.description

        target_minimum_version = self.target_minimum_version

        indexing_settings: dict[str, Any] | Unset = UNSET
        if not isinstance(self.indexing_settings, Unset):
            indexing_settings = self.indexing_settings.to_dict()

        enabled = self.enabled

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "indexerRid": indexer_rid,
                "targetUri": target_uri,
                "namespace": namespace,
                "trigger": trigger,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description
        if target_minimum_version is not UNSET:
            field_dict["targetMinimumVersion"] = target_minimum_version
        if indexing_settings is not UNSET:
            field_dict["indexingSettings"] = indexing_settings
        if enabled is not UNSET:
            field_dict["enabled"] = enabled

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_indexing_schedule_request_indexing_settings import (
            CreateIndexingScheduleRequestIndexingSettings,
        )
        from ..models.cron_trigger import CronTrigger
        from ..models.interval_trigger import IntervalTrigger
        from ..models.on_upload_trigger import OnUploadTrigger

        d = dict(src_dict)
        name = d.pop("name")

        indexer_rid = d.pop("indexerRid")

        target_uri = d.pop("targetUri")

        namespace = d.pop("namespace")

        def _parse_trigger(data: object) -> CronTrigger | IntervalTrigger | OnUploadTrigger:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schedule_trigger_type_0 = OnUploadTrigger.from_dict(data)

                return componentsschemas_schedule_trigger_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schedule_trigger_type_1 = CronTrigger.from_dict(data)

                return componentsschemas_schedule_trigger_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_schedule_trigger_type_2 = IntervalTrigger.from_dict(data)

            return componentsschemas_schedule_trigger_type_2

        trigger = _parse_trigger(d.pop("trigger"))

        description = d.pop("description", UNSET)

        target_minimum_version = d.pop("targetMinimumVersion", UNSET)

        _indexing_settings = d.pop("indexingSettings", UNSET)
        indexing_settings: CreateIndexingScheduleRequestIndexingSettings | Unset
        if isinstance(_indexing_settings, Unset):
            indexing_settings = UNSET
        else:
            indexing_settings = CreateIndexingScheduleRequestIndexingSettings.from_dict(_indexing_settings)

        enabled = d.pop("enabled", UNSET)

        create_indexing_schedule_request = cls(
            name=name,
            indexer_rid=indexer_rid,
            target_uri=target_uri,
            namespace=namespace,
            trigger=trigger,
            description=description,
            target_minimum_version=target_minimum_version,
            indexing_settings=indexing_settings,
            enabled=enabled,
        )

        create_indexing_schedule_request.additional_properties = d
        return create_indexing_schedule_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.json_node_type import JsonNodeType
from ..types import UNSET, Unset

T = TypeVar("T", bound="JsonNode")


@_attrs_define
class JsonNode:
    """
    Attributes:
        empty (bool | Unset):
        value_node (bool | Unset):
        container_node (bool | Unset):
        missing_node (bool | Unset):
        array (bool | Unset):
        object_ (bool | Unset):
        node_type (JsonNodeType | Unset):
        pojo (bool | Unset):
        number (bool | Unset):
        integral_number (bool | Unset):
        floating_point_number (bool | Unset):
        short (bool | Unset):
        int_ (bool | Unset):
        long (bool | Unset):
        float_ (bool | Unset):
        double (bool | Unset):
        big_decimal (bool | Unset):
        big_integer (bool | Unset):
        textual (bool | Unset):
        boolean (bool | Unset):
        null (bool | Unset):
        binary (bool | Unset):
    """

    empty: bool | Unset = UNSET
    value_node: bool | Unset = UNSET
    container_node: bool | Unset = UNSET
    missing_node: bool | Unset = UNSET
    array: bool | Unset = UNSET
    object_: bool | Unset = UNSET
    node_type: JsonNodeType | Unset = UNSET
    pojo: bool | Unset = UNSET
    number: bool | Unset = UNSET
    integral_number: bool | Unset = UNSET
    floating_point_number: bool | Unset = UNSET
    short: bool | Unset = UNSET
    int_: bool | Unset = UNSET
    long: bool | Unset = UNSET
    float_: bool | Unset = UNSET
    double: bool | Unset = UNSET
    big_decimal: bool | Unset = UNSET
    big_integer: bool | Unset = UNSET
    textual: bool | Unset = UNSET
    boolean: bool | Unset = UNSET
    null: bool | Unset = UNSET
    binary: bool | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        empty = self.empty

        value_node = self.value_node

        container_node = self.container_node

        missing_node = self.missing_node

        array = self.array

        object_ = self.object_

        node_type: str | Unset = UNSET
        if not isinstance(self.node_type, Unset):
            node_type = self.node_type.value

        pojo = self.pojo

        number = self.number

        integral_number = self.integral_number

        floating_point_number = self.floating_point_number

        short = self.short

        int_ = self.int_

        long = self.long

        float_ = self.float_

        double = self.double

        big_decimal = self.big_decimal

        big_integer = self.big_integer

        textual = self.textual

        boolean = self.boolean

        null = self.null

        binary = self.binary

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if empty is not UNSET:
            field_dict["empty"] = empty
        if value_node is not UNSET:
            field_dict["valueNode"] = value_node
        if container_node is not UNSET:
            field_dict["containerNode"] = container_node
        if missing_node is not UNSET:
            field_dict["missingNode"] = missing_node
        if array is not UNSET:
            field_dict["array"] = array
        if object_ is not UNSET:
            field_dict["object"] = object_
        if node_type is not UNSET:
            field_dict["nodeType"] = node_type
        if pojo is not UNSET:
            field_dict["pojo"] = pojo
        if number is not UNSET:
            field_dict["number"] = number
        if integral_number is not UNSET:
            field_dict["integralNumber"] = integral_number
        if floating_point_number is not UNSET:
            field_dict["floatingPointNumber"] = floating_point_number
        if short is not UNSET:
            field_dict["short"] = short
        if int_ is not UNSET:
            field_dict["int"] = int_
        if long is not UNSET:
            field_dict["long"] = long
        if float_ is not UNSET:
            field_dict["float"] = float_
        if double is not UNSET:
            field_dict["double"] = double
        if big_decimal is not UNSET:
            field_dict["bigDecimal"] = big_decimal
        if big_integer is not UNSET:
            field_dict["bigInteger"] = big_integer
        if textual is not UNSET:
            field_dict["textual"] = textual
        if boolean is not UNSET:
            field_dict["boolean"] = boolean
        if null is not UNSET:
            field_dict["null"] = null
        if binary is not UNSET:
            field_dict["binary"] = binary

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        empty = d.pop("empty", UNSET)

        value_node = d.pop("valueNode", UNSET)

        container_node = d.pop("containerNode", UNSET)

        missing_node = d.pop("missingNode", UNSET)

        array = d.pop("array", UNSET)

        object_ = d.pop("object", UNSET)

        _node_type = d.pop("nodeType", UNSET)
        node_type: JsonNodeType | Unset
        if isinstance(_node_type, Unset):
            node_type = UNSET
        else:
            node_type = JsonNodeType(_node_type)

        pojo = d.pop("pojo", UNSET)

        number = d.pop("number", UNSET)

        integral_number = d.pop("integralNumber", UNSET)

        floating_point_number = d.pop("floatingPointNumber", UNSET)

        short = d.pop("short", UNSET)

        int_ = d.pop("int", UNSET)

        long = d.pop("long", UNSET)

        float_ = d.pop("float", UNSET)

        double = d.pop("double", UNSET)

        big_decimal = d.pop("bigDecimal", UNSET)

        big_integer = d.pop("bigInteger", UNSET)

        textual = d.pop("textual", UNSET)

        boolean = d.pop("boolean", UNSET)

        null = d.pop("null", UNSET)

        binary = d.pop("binary", UNSET)

        json_node = cls(
            empty=empty,
            value_node=value_node,
            container_node=container_node,
            missing_node=missing_node,
            array=array,
            object_=object_,
            node_type=node_type,
            pojo=pojo,
            number=number,
            integral_number=integral_number,
            floating_point_number=floating_point_number,
            short=short,
            int_=int_,
            long=long,
            float_=float_,
            double=double,
            big_decimal=big_decimal,
            big_integer=big_integer,
            textual=textual,
            boolean=boolean,
            null=null,
            binary=binary,
        )

        json_node.additional_properties = d
        return json_node

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.image_detection_box_api_dto import ImageDetectionBoxApiDto


T = TypeVar("T", bound="BiotechAnalysisApiDto")


@_attrs_define
class BiotechAnalysisApiDto:
    """
    Attributes:
        raw_analysis (str | Unset):
        compound_data_present (bool | Unset):
        compounds (list[str] | Unset):
        development_stage (str | Unset):
        therapeutic_area (str | Unset):
        key_findings (list[str] | Unset):
        risks (list[str] | Unset):
        market_potential (str | Unset):
        confidence (float | Unset):
        reasoning (str | Unset):
        bounding_boxes (list[ImageDetectionBoxApiDto] | Unset):
        page_index (int | Unset):
        character_count (int | Unset):
    """

    raw_analysis: str | Unset = UNSET
    compound_data_present: bool | Unset = UNSET
    compounds: list[str] | Unset = UNSET
    development_stage: str | Unset = UNSET
    therapeutic_area: str | Unset = UNSET
    key_findings: list[str] | Unset = UNSET
    risks: list[str] | Unset = UNSET
    market_potential: str | Unset = UNSET
    confidence: float | Unset = UNSET
    reasoning: str | Unset = UNSET
    bounding_boxes: list[ImageDetectionBoxApiDto] | Unset = UNSET
    page_index: int | Unset = UNSET
    character_count: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        raw_analysis = self.raw_analysis

        compound_data_present = self.compound_data_present

        compounds: list[str] | Unset = UNSET
        if not isinstance(self.compounds, Unset):
            compounds = self.compounds

        development_stage = self.development_stage

        therapeutic_area = self.therapeutic_area

        key_findings: list[str] | Unset = UNSET
        if not isinstance(self.key_findings, Unset):
            key_findings = self.key_findings

        risks: list[str] | Unset = UNSET
        if not isinstance(self.risks, Unset):
            risks = self.risks

        market_potential = self.market_potential

        confidence = self.confidence

        reasoning = self.reasoning

        bounding_boxes: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.bounding_boxes, Unset):
            bounding_boxes = []
            for bounding_boxes_item_data in self.bounding_boxes:
                bounding_boxes_item = bounding_boxes_item_data.to_dict()
                bounding_boxes.append(bounding_boxes_item)

        page_index = self.page_index

        character_count = self.character_count

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if raw_analysis is not UNSET:
            field_dict["rawAnalysis"] = raw_analysis
        if compound_data_present is not UNSET:
            field_dict["compoundDataPresent"] = compound_data_present
        if compounds is not UNSET:
            field_dict["compounds"] = compounds
        if development_stage is not UNSET:
            field_dict["developmentStage"] = development_stage
        if therapeutic_area is not UNSET:
            field_dict["therapeuticArea"] = therapeutic_area
        if key_findings is not UNSET:
            field_dict["keyFindings"] = key_findings
        if risks is not UNSET:
            field_dict["risks"] = risks
        if market_potential is not UNSET:
            field_dict["marketPotential"] = market_potential
        if confidence is not UNSET:
            field_dict["confidence"] = confidence
        if reasoning is not UNSET:
            field_dict["reasoning"] = reasoning
        if bounding_boxes is not UNSET:
            field_dict["boundingBoxes"] = bounding_boxes
        if page_index is not UNSET:
            field_dict["pageIndex"] = page_index
        if character_count is not UNSET:
            field_dict["characterCount"] = character_count

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.image_detection_box_api_dto import ImageDetectionBoxApiDto

        d = dict(src_dict)
        raw_analysis = d.pop("rawAnalysis", UNSET)

        compound_data_present = d.pop("compoundDataPresent", UNSET)

        compounds = cast(list[str], d.pop("compounds", UNSET))

        development_stage = d.pop("developmentStage", UNSET)

        therapeutic_area = d.pop("therapeuticArea", UNSET)

        key_findings = cast(list[str], d.pop("keyFindings", UNSET))

        risks = cast(list[str], d.pop("risks", UNSET))

        market_potential = d.pop("marketPotential", UNSET)

        confidence = d.pop("confidence", UNSET)

        reasoning = d.pop("reasoning", UNSET)

        _bounding_boxes = d.pop("boundingBoxes", UNSET)
        bounding_boxes: list[ImageDetectionBoxApiDto] | Unset = UNSET
        if _bounding_boxes is not UNSET:
            bounding_boxes = []
            for bounding_boxes_item_data in _bounding_boxes:
                bounding_boxes_item = ImageDetectionBoxApiDto.from_dict(bounding_boxes_item_data)

                bounding_boxes.append(bounding_boxes_item)

        page_index = d.pop("pageIndex", UNSET)

        character_count = d.pop("characterCount", UNSET)

        biotech_analysis_api_dto = cls(
            raw_analysis=raw_analysis,
            compound_data_present=compound_data_present,
            compounds=compounds,
            development_stage=development_stage,
            therapeutic_area=therapeutic_area,
            key_findings=key_findings,
            risks=risks,
            market_potential=market_potential,
            confidence=confidence,
            reasoning=reasoning,
            bounding_boxes=bounding_boxes,
            page_index=page_index,
            character_count=character_count,
        )

        biotech_analysis_api_dto.additional_properties = d
        return biotech_analysis_api_dto

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.list_indexing_schedules_response import ListIndexingSchedulesResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    enabled: bool | Unset = UNSET,
    file_system_rid: str | Unset = UNSET,
    limit: int | Unset = 100,
    offset: int | Unset = 0,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["enabled"] = enabled

    params["fileSystemRid"] = file_system_rid

    params["limit"] = limit

    params["offset"] = offset

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/indexing/schedules",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> ListIndexingSchedulesResponse | None:
    if response.status_code == 200:
        response_200 = ListIndexingSchedulesResponse.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[ListIndexingSchedulesResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    enabled: bool | Unset = UNSET,
    file_system_rid: str | Unset = UNSET,
    limit: int | Unset = 100,
    offset: int | Unset = 0,
) -> Response[ListIndexingSchedulesResponse]:
    """List indexing schedules

    Args:
        enabled (bool | Unset):
        file_system_rid (str | Unset):
        limit (int | Unset):  Default: 100.
        offset (int | Unset):  Default: 0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ListIndexingSchedulesResponse]
    """

    kwargs = _get_kwargs(
        enabled=enabled,
        file_system_rid=file_system_rid,
        limit=limit,
        offset=offset,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient | Client,
    enabled: bool | Unset = UNSET,
    file_system_rid: str | Unset = UNSET,
    limit: int | Unset = 100,
    offset: int | Unset = 0,
) -> ListIndexingSchedulesResponse | None:
    """List indexing schedules

    Args:
        enabled (bool | Unset):
        file_system_rid (str | Unset):
        limit (int | Unset):  Default: 100.
        offset (int | Unset):  Default: 0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ListIndexingSchedulesResponse
    """

    return sync_detailed(
        client=client,
        enabled=enabled,
        file_system_rid=file_system_rid,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    enabled: bool | Unset = UNSET,
    file_system_rid: str | Unset = UNSET,
    limit: int | Unset = 100,
    offset: int | Unset = 0,
) -> Response[ListIndexingSchedulesResponse]:
    """List indexing schedules

    Args:
        enabled (bool | Unset):
        file_system_rid (str | Unset):
        limit (int | Unset):  Default: 100.
        offset (int | Unset):  Default: 0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ListIndexingSchedulesResponse]
    """

    kwargs = _get_kwargs(
        enabled=enabled,
        file_system_rid=file_system_rid,
        limit=limit,
        offset=offset,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    enabled: bool | Unset = UNSET,
    file_system_rid: str | Unset = UNSET,
    limit: int | Unset = 100,
    offset: int | Unset = 0,
) -> ListIndexingSchedulesResponse | None:
    """List indexing schedules

    Args:
        enabled (bool | Unset):
        file_system_rid (str | Unset):
        limit (int | Unset):  Default: 100.
        offset (int | Unset):  Default: 0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ListIndexingSchedulesResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            enabled=enabled,
            file_system_rid=file_system_rid,
            limit=limit,
            offset=offset,
        )
    ).parsed
